AndroidCnOaid class

Flutter 插件 android_cn_oaid 的公开 API 类。

所有方法仅支持 Android 平台,在其他平台调用会抛出 UnsupportedError

Constructors

AndroidCnOaid()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getAndroidID() Future<String?>
获取 AndroidID,可能为 null。
getGUID() Future<String>
获取 GUID,返回值不为空。
getOAID() Future<String?>
异步获取 OAID 或 AAID,不支持时返回 null。
getOAIDByManufacturer() Future<String?>
优先使用厂商专有接口异步获取广告标识符,不支持时返回 null。
getPseudoID() Future<String>
获取 PseudoID,返回值不为空。
getSupportedManufacturers() Future<List<String>>
获取当前插件支持的厂商名称列表。
isSupported() Future<bool>
查询当前设备是否支持 OAID 或 AAID。
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
register() Future<void>
预初始化 OAID 服务,需在用户同意隐私政策后调用。
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited