MethodChannelAndroidCnOaid class
AndroidCnOaidPlatform 的默认实现,通过 MethodChannel 与原生层通信。
- Inheritance
-
- Object
- PlatformInterface
- AndroidCnOaidPlatform
- MethodChannelAndroidCnOaid
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- methodChannel → MethodChannel
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getAndroidID(
) → Future< String?> -
获取 AndroidID(可能为 null)
override
-
getGUID(
) → Future< String> -
获取 GUID(不为空)
override
-
getOAID(
) → Future< String?> -
异步获取 OAID 或 AAID
override
-
getOAIDByManufacturer(
) → Future< String?> -
优先使用厂商专有接口异步获取广告标识符
override
-
getPseudoID(
) → Future< String> -
获取 PseudoID(不为空)
override
-
getSupportedManufacturers(
) → Future< List< String> > -
获取当前插件支持的厂商名称列表
override
-
isSupported(
) → Future< bool> -
查询当前设备是否支持 OAID 或 AAID
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
register(
) → Future< void> -
预初始化 OAID 服务(需在用户同意隐私政策后调用)
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited