OaidException class

表示来自 Android 原生层的结构化异常。

MethodChannelAndroidCnOaid 捕获到 PlatformException 时, 将其转换为 OaidException 后重新抛出,便于调用方按错误码分类处理。

Implemented types

Constructors

OaidException({required String code, String? message})
const

Properties

code String
错误码,如 "oaid_error""permission_denied"
final
hashCode int
The hash code for this object.
no setterinherited
message String?
错误描述,可为 null。
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited